@@ -25,9 +25,9 @@
 #'          is detected automatically. If \code{x} is a vector, \code{fun} defaults
 #'          to \code{"lm"}.
 #' @param axisTitle.x A label for the x axis. Use \code{NULL} to automatically detect 
-#'          variable names that will be used as title (see \code{\link[sjmisc]{set_var_labels}}) for details).
+#'          variable names that will be used as title (see \code{\link[sjmisc]{set_label}}) for details).
 #' @param axisTitle.y A label for the y axis. Use \code{NULL} to automatically detect 
-#'          variable names that will be used as title (see \code{\link[sjmisc]{set_var_labels}}) for details).
+#'          variable names that will be used as title (see \code{\link[sjmisc]{set_label}}) for details).
 #' @param showScatterPlot If \code{TRUE} (default), a scatter plot of response and predictor values
 #'          for each predictor of the fitted model \code{fit} is plotted.
 #'          Only applies if \code{type = "lm"} and fitted model has only one predictor,
@@ -45,9 +45,12 @@
 #' @param pointAlpha The alpha values of the scatter plot's point-geoms. Default is 0.2.
 #' @param printPlot If \code{TRUE} (default), plots the results as graph. Use \code{FALSE} if you don't
 #'          want to plot any graphs. In either case, the ggplot-object will be returned as value.
-#' @return (insisibily) returns the ggplot-object with the complete plot (\code{plot})
-#'           as well as the data frame that was used for setting up the
-#'           ggplot-object (\code{df}).
+#' @return (insisibily) returns 
+#'           \describe{
+#'            \item{\code{plot}}{the ggplot-object with the complete plot}
+#'            \item{\code{df}}{the data frame that was used for setting up the ggplot-object}
+#'            \item{\code{cutpoints}}{a data frame that indicates x-values and predicted y-values of each direction change in the loess curvature}
+#'           }
 #' 
 #' @details For each polynomial degree, a simple linear regression on \code{x} (resp.
 #'            the extracted response, if \code{x} is a fitted model) is performed,
@@ -59,7 +62,7 @@
 #'            finding the best fitting polynomial. \cr \cr
 #'            This function evaluates raw polynomials, \emph{not orthogonal} polynomials.
 #'            Polynomials are computed using the \code{\link{poly}} function,
-#'            with parameter \code{raw = TRUE}. \cr \cr
+#'            with argument \code{raw = TRUE}. \cr \cr
 #'            To find out which polynomial degree fits best to the data, a loess-smoothed
 #'            line can be added (with \code{showLoess = TRUE}). The polynomial curves
 #'            that comes closest to the loess-smoothed line should be the best
@@ -106,7 +109,7 @@
 #' 
 #' @import ggplot2
 #' @importFrom scales grey_pal brewer_pal
-#' @importFrom stats lm glm binomial
+#' @importFrom stats lm glm binomial predict
 #' @export
 sjp.poly <- function(x, 
                      poly.term, 
@@ -173,6 +176,10 @@ sjp.poly <- function(x,
   # scale polynomial term?
   if (poly.scale) poly.term <- scale(poly.term)
   # --------------------------------------------
+  # get cutpoints for loess curve
+  # --------------------------------------------
+  cutpoints <- get_loess_cutpoints(na.omit(data.frame(x = poly.term, y = resp)))
+  # --------------------------------------------
   # if user wants to plot multiple curves for
   # polynomials, create data frame for each curve here
   # --------------------------------------------
@@ -189,7 +196,9 @@ sjp.poly <- function(x,
     # or a float value
     poly.digit <- ifelse(i %% 1 == 0, 0, 1)
     # create data frame with raw data and the fitted poly-curve
-    plot.df <- rbind(plot.df, cbind(mydat, predict(fit), sprintf("x^%.*f", poly.digit, i)))
+    plot.df <- rbind(plot.df, cbind(mydat, 
+                                    stats::predict(fit), 
+                                    sprintf("x^%.*f", poly.digit, i)))
     # print p-values?
     if (showPValues) {
       # get p-values
@@ -230,5 +239,44 @@ sjp.poly <- function(x,
   # -------------------------------------
   invisible(structure(class = "sjppoly",
                       list(plot = polyplot,
-                           df = plot.df)))
+                           df = plot.df,
+                           cutpoints = cutpoints)))
 }
+
+
+#' @importFrom stats loess predict
+get_loess_cutpoints <- function(mydat) {
+  # sort data frame by x-values
+  mydat <- mydat[order(mydat$x), ]
+  # fit loess
+  fit <- stats::loess(y ~ x, mydat)
+  # get predicted values
+  preds <- unique(stats::predict(fit))
+  xuni <- unique(mydat$x)
+  # define counter
+  cnt <- 1
+  cutpoints <- c()
+  xvals <- c()
+  # initial direction for finding first cutpoint?
+  direction <- ifelse(preds[cnt + 1] > preds[cnt], "up", "down")
+  # "follow" path of loess line until cutpoint
+  # then save value and change direction
+  while (cnt < length(preds)) {
+    if (direction == "up") {
+      if (preds[cnt + 1] < preds[cnt]) {
+        direction <- "down"
+        cutpoints <- c(cutpoints, preds[cnt])
+        xvals <- c(xvals, xuni[cnt])
+      }
+    } else {
+      if (preds[cnt + 1] > preds[cnt]) {
+        direction <- "up"
+        cutpoints <- c(cutpoints, preds[cnt])
+        xvals <- c(xvals, xuni[cnt])
+      }
+    }
+    cnt <- cnt + 1
+  }
+  
+  return(data.frame(cutpoint.x = xvals, cutpoint.y = cutpoints))
+}
\ No newline at end of file
