@@ -159,7 +159,7 @@ sjt.corr <- function(data,
   # --------------------------------------------------------
   # check encoding
   # --------------------------------------------------------
-  encoding <- get.encoding(encoding)
+  encoding <- get.encoding(encoding, data)
   # --------------------------------------------------------
   # argument check
   # --------------------------------------------------------
